from django.conf.urls import url
from django.views.generic.base import RedirectView

from django_sso_app.views import SsoAdminAuthUser

urlpatterns = [
    url(r"^auth/user/$", SsoAdminAuthUser.as_view(), name="sso_admin_auth_user"),
    url(r"^auth/user/", RedirectView.as_view(url=None, permanent=True)),
]



from django.contrib.auth.decorators import login_required
from django.http.response import HttpResponseRedirect
from django.utils.decorators import method_decorator
from django.views.generic import TemplateView

from . import settings


class SsoAdminAuthUser(TemplateView):
    @method_decorator(login_required)
    def dispatch(self, request, *args, **kwargs):
        redirect_url = settings.DJANGO_SSO_ADMIN_USER_URL
        return HttpResponseRedirect(redirect_to=redirect_url)
